@@ -15,10 +15,10 @@
 """Storage backend management
 """
 
+from urllib import parse as urlparse
+
 from oslo_config import cfg
 from oslo_log import log
-import six
-import six.moves.urllib.parse as urlparse
 from stevedore import driver
 import tenacity
 
@@ -32,6 +32,11 @@ OPTS = [
                default=-1,
                help=("Number of seconds that events are kept "
                      "in the database for (<= 0 means forever).")),
+    cfg.IntOpt('events_delete_batch_size',
+               default=0,
+               min=0,
+               help=("Number of events to be deleted in one iteration "
+                     "from the database for (0 means all).")),
     cfg.StrOpt('event_connection',
                secret=True,
                deprecated_for_removal=True,
@@ -133,4 +138,4 @@ class EventFilter(object):
                 (self.start_timestamp,
                  self.end_timestamp,
                  self.event_type,
-                 six.text_type(self.traits_filter)))
+                 str(self.traits_filter)))
