@@ -21,10 +21,9 @@ from oslo_log import log
 from oslo_utils import netutils
 import pymongo
 import pymongo.errors
-import six
 import tenacity
 
-from panko.i18n import _, _LI
+from panko.i18n import _
 
 ERROR_INDEX_WITH_DIFFERENT_SPEC_ALREADY_EXISTS = 86
 
@@ -86,7 +85,7 @@ def make_events_query_from_filter(event_filter):
         for trait_filter in event_filter.traits_filter:
             op = trait_filter.pop('op', 'eq')
             dict_query = {}
-            for k, v in six.iteritems(trait_filter):
+            for k, v in trait_filter.items():
                 if v is not None:
                     # All parameters in EventFilter['traits'] are optional, so
                     # we need to check if they are in the query or no.
@@ -132,7 +131,7 @@ class ConnectionPool(object):
         splitted_url = netutils.urlsplit(url)
         log_data = {'db': splitted_url.scheme,
                     'nodelist': connection_options['nodelist']}
-        LOG.info(_LI('Connecting to %(db)s on %(nodelist)s') % log_data)
+        LOG.info('Connecting to %(db)s on %(nodelist)s' % log_data)
         try:
             client = MongoProxy(pymongo.MongoClient(url),
                                 max_retries, retry_interval)
@@ -190,7 +189,7 @@ class MongoProxy(object):
             self.conn.create_index(keys, name=name, *args, **kwargs)
         except pymongo.errors.OperationFailure as e:
             if e.code is ERROR_INDEX_WITH_DIFFERENT_SPEC_ALREADY_EXISTS:
-                LOG.info(_LI("Index %s will be recreate.") % name)
+                LOG.info("Index %s will be recreate." % name)
                 self._recreate_index(keys, name, *args, **kwargs)
 
     def _recreate_index(self, keys, name, *args, **kwargs):
