@@ -18,14 +18,13 @@
 import datetime
 import os
 from unittest import case
+from urllib import parse as urlparse
 
 from gabbi import fixture
 from oslo_config import cfg
 from oslo_policy import opts
 from oslo_utils import fileutils
 from oslo_utils import uuidutils
-import six
-from six.moves.urllib import parse as urlparse
 import sqlalchemy_utils
 
 from panko.api import app
@@ -65,8 +64,7 @@ class ConfigFixture(fixture.GabbiFixture):
         opts.set_defaults(self.conf)
 
         content = ('{"default": ""}')
-        if six.PY3:
-            content = content.encode('utf-8')
+        content = content.encode('utf-8')
         self.tempfile = fileutils.write_to_tempfile(content=content,
                                                     prefix='policy',
                                                     suffix='.json')
@@ -75,8 +73,7 @@ class ConfigFixture(fixture.GabbiFixture):
                           group='oslo_policy')
         conf.set_override(
             'api_paste_config',
-            os.path.abspath(
-                'panko/tests/functional/gabbi/gabbi_paste.ini')
+            os.path.abspath('etc/panko/api_paste.ini')
         )
 
         parsed_url = list(urlparse.urlparse(db_url))
@@ -93,7 +90,7 @@ class ConfigFixture(fixture.GabbiFixture):
         self.conn.upgrade()
 
         LOAD_APP_KWARGS = {
-            'conf': conf,
+            'conf': conf, 'appname': 'panko+noauth',
         }
 
     def stop_fixture(self):
